@@ -172,7 +172,7 @@ void on_save_as_cb(BonoboUIComponent *uic, gpointer user_data, const char *cname
 {
 	g_return_if_fail (GC_BONOBO_IS_CONTROL (user_data));
 	GCBonoboControl* control = GC_BONOBO_CONTROL (user_data);
-	gcFileSel* FileSel = new gcFileSel(_("Save model as..."), do_save_as, true, ".gcrystal", (gcView*)control->ps->pDoc->GetView());
+	new gcFileSel(_("Save model as..."), do_save_as, true, ".gcrystal", (gcView*)control->ps->pDoc->GetView());
 }
 
 void on_print_cb(BonoboUIComponent *uic, gpointer user_data, const char *cname)
@@ -182,7 +182,7 @@ void on_print_cb(BonoboUIComponent *uic, gpointer user_data, const char *cname)
 	GnomePrintConfig* config = gnome_print_config_default();
 	GnomePrintContext *pc;
 	GnomePrintJob *gpj = gnome_print_job_new(config);
-	int do_preview, copies = 1, collate = 0;
+	int do_preview = 0, copies = 1, collate = 0;
 	GnomePrintDialog *gpd;
 	gpd = GNOME_PRINT_DIALOG (gnome_print_dialog_new(gpj, (const guchar*)"Print test", GNOME_PRINT_DIALOG_COPIES));
 	gnome_print_dialog_set_copies(gpd, copies, collate);
@@ -225,7 +225,7 @@ void on_export_vrml_cb(BonoboUIComponent *uic, gpointer user_data, const char *c
 {
 	g_return_if_fail (GC_BONOBO_IS_CONTROL (user_data));
 	GCBonoboControl* control = GC_BONOBO_CONTROL (user_data);
-	gcFileSel* FileSel = new gcFileSel(_("Export model as a VRML file..."), do_export_vrml, true, ".wrl", (gcView*)control->ps->pDoc->GetView());
+	new gcFileSel(_("Export model as a VRML file..."), do_export_vrml, true, ".wrl", (gcView*)control->ps->pDoc->GetView());
 }
 
 void do_export_vrml(const gchar* filename, gcView* pView);
@@ -239,7 +239,7 @@ void on_export_png_cb(BonoboUIComponent *uic, gpointer user_data, const char *cn
 #ifdef HAVE_LIBPNG
 	g_return_if_fail (GC_BONOBO_IS_CONTROL (user_data));
 	GCBonoboControl* control = GC_BONOBO_CONTROL (user_data);
-	gcFileSel* FileSel = new gcFileSel(_("Export model as a PNG file..."), do_export_png, true, ".png", (gcView*)control->ps->pDoc->GetView());
+	new gcFileSel(_("Export model as a PNG file..."), do_export_png, true, ".png", (gcView*)control->ps->pDoc->GetView());
 #endif
 }
 
@@ -252,13 +252,13 @@ void on_export_jpeg_cb(BonoboUIComponent *uic, gpointer user_data, const char *c
 #ifdef HAVE_LIBJPEG
 	g_return_if_fail (GC_BONOBO_IS_CONTROL (user_data));
 	GCBonoboControl* control = GC_BONOBO_CONTROL (user_data);
-	gcFileSel* FileSel = new gcFileSel(_("Export model as a Jpeg file..."), do_export_jpeg, true, ".jpg", (gcView*)control->ps->pDoc->GetView());
+	new gcFileSel(_("Export model as a Jpeg file..."), do_export_jpeg, true, ".jpg", (gcView*)control->ps->pDoc->GetView());
 #endif
 }
 
 void on_preferences_cb(BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
-	gcPrefsDlg* box = new gcPrefsDlg();
+	new gcPrefsDlg();
 }
 
 void on_lattice_cb(BonoboUIComponent *uic, gpointer user_data, const char *cname)
@@ -300,7 +300,7 @@ void on_view_settings_cb(BonoboUIComponent *uic, gpointer user_data, const char
 {
 	g_return_if_fail (GC_BONOBO_IS_CONTROL (user_data));
 	GCBonoboControl* control = GC_BONOBO_CONTROL (user_data);
-	gcViewSettingsDlg* pDlg = new gcViewSettingsDlg((gcView*)control->ps->pDoc->GetView());
+	new gcViewSettingsDlg((gcView*)control->ps->pDoc->GetView());
 }
 
 void on_about();
@@ -384,8 +384,6 @@ BONOBO_TYPE_FUNC (GCBonoboControl, BONOBO_TYPE_CONTROL, gc_bonobo_control);
 GCBonoboControl* gc_bonobo_control_construct(GCBonoboControl *control, gcDocument *pDoc)
 {
 	GtkWidget             *widget;
-	BonoboPropertyBag     *pb;
-	BonoboPropertyControl *pc;
 	
 	g_return_val_if_fail (pDoc != NULL, NULL);
 	g_return_val_if_fail (control != NULL, NULL);
@@ -416,128 +414,6 @@ gc_bonobo_control_new (gcDocument *pDoc)
 
 	return gc_bonobo_control_construct (control, pDoc);
 }
-/*static void gcrystal_object_print(GnomePrintContext *ctx, double width, double height, const Bonobo_PrintScissor *scissor, embeddable_data_t *data)
-{
-	gcView* pView =  data->pDoc->GetView();
-	pView->Print(ctx, width, height);
-}*/
-
-
-/*static void on_embeddable_exception(BonoboEmbeddable *embeddable, CORBA_Object object, CORBA_Environment *ev, gpointer data)
-{
-	bonobo_object_unref(BONOBO_OBJECT(embeddable));
-}*/
-
-/*static void on_embeddable_destroy(BonoboEmbeddable *embeddable, embeddable_data_t *data)
-{
-	RemoveDocument(data->pDoc);
-	delete data;
-}*/
-
-/*static void on_view_exception(BonoboView *view, CORBA_Object object, CORBA_Environment *ev, gpointer data)
-{
-	bonobo_object_unref(BONOBO_OBJECT(view));
-}*/
-
-/*static void on_view_destroy(BonoboView *view, view_data_t *data)
-{
-	gtk_widget_destroy(data->widget);
-	delete data;
-}*/
-
-/*static void do_load(const gchar* filename, gcView *pView)
-{
-	gcDocument* pDoc = pView->GetDocument();
-	if (pDoc) pDoc->Load(filename);
-}*/
-
-/*static void on_lattice(BonoboUIComponent *uic, view_data_t* data, const char *cname)
-{
-	gcDocument* pDoc = data->pView->GetDocument();
-	if (pDoc) pDoc->Define();
-}*/
-
-/*static void on_atoms(BonoboUIComponent *uic, view_data_t* data, const char *cname)
-{
-	gcDocument* pDoc = data->pView->GetDocument();
-	if (pDoc) pDoc->Define(1);
-}*/
-
-/*static void on_bonds(BonoboUIComponent *uic, view_data_t* data, const char *cname)
-{
-	gcDocument* pDoc = data->pView->GetDocument();
-	if (pDoc) pDoc->Define(2);
-}*/
-
-/*static void on_size(BonoboUIComponent *uic, view_data_t* data, const char *cname)
-{
-	gcDocument* pDoc = data->pView->GetDocument();
-	if (pDoc) pDoc->Define(3);
-}*/
-
-/*static void on_cleavages(BonoboUIComponent *uic, view_data_t* data, const char *cname)
-{
-	gcDocument* pDoc = data->pView->GetDocument();
-	if (pDoc) pDoc->Define(4);
-}*/
-
-/*static void on_view_settings(BonoboUIComponent *uic, view_data_t* data, const char *cname)
-{
-	if (!data->pView) return;
-	gcViewSettingsDlg* pDlg = new gcViewSettingsDlg(data->pView);
-}*/
-
-/*static void on_view_activate(BonoboView *view, gboolean activate, view_data_t *data)
-{
-	bonobo_view_activate_notify(view, activate);
-	BonoboUIComponent *uic = bonobo_view_get_ui_component(data->view);
-	if (activate)
-	{
-		Bonobo_UIContainer remote_uic = bonobo_view_get_remote_ui_container(data->view);
-
-		if (remote_uic == CORBA_OBJECT_NIL)
-		{
-			g_warning(_("Can't get remote UIContainer"));
-			return;
-		}
-		bonobo_ui_component_set_container(uic, remote_uic);
-
-		static BonoboUIVerb my_ui_verbs[] = {
-			BONOBO_UI_VERB ("Lattice", (void (*)(BonoboUIComponent*, void*, const char*)) on_lattice),
-			BONOBO_UI_VERB ("Atoms", (void (*)(BonoboUIComponent*, void*, const char*)) on_atoms),
-			BONOBO_UI_VERB ("Bonds", (void (*)(BonoboUIComponent*, void*, const char*)) on_bonds),
-			BONOBO_UI_VERB ("Size", (void (*)(BonoboUIComponent*, void*, const char*)) on_size),
-			BONOBO_UI_VERB ("Cleavages", (void (*)(BonoboUIComponent*, void*, const char*)) on_cleavages),
-			BONOBO_UI_VERB ("ViewSettings", (void (*)(BonoboUIComponent*, void*, const char*)) on_view_settings),
-			BONOBO_UI_VERB_END
-		};
-
-		bonobo_ui_util_set_ui (uic, PREFIX, "gcrystal.xml", "gcrystal");
-		bonobo_ui_component_add_verb_list_with_data (uic, my_ui_verbs, data);
-		bonobo_ui_component_thaw(uic, NULL);
-	}
-	else
-	{
-		bonobo_ui_component_unset_container(uic);
-	}
-}*/
-
-/*static BonoboView * view_factory(BonoboEmbeddable *embeddable, const Bonobo_ViewFrame view_frame, embeddable_data_t *data)
-{
-	view_data_t *view_data = new view_data_t;
-	view_data->data = data;
-	view_data->pView = data->pDoc->GetView();
-	view_data->widget = view_data->pView->CreateNewWidget();
-	GtkWidget *vbox = gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox), view_data->widget, TRUE, TRUE, 0);
-	gtk_widget_show_all(vbox);
-	BonoboView *view = bonobo_view_new(vbox);
-	view_data->view = view;
-	g_signal_connect(GTK_OBJECT(view), "activate", GTK_SIGNAL_FUNC(on_view_activate), view_data);
-	g_signal_connect(G_OBJECT(view), "system_exception", GTK_SIGNAL_FUNC(on_view_exception), view_data);
-	g_signal_connect(G_OBJECT(view), "destroy", GTK_SIGNAL_FUNC(on_view_destroy), view_data);
-	return view;
-}*/
 
 BonoboObject * gcrystal_factory(BonoboGenericFactory * fact, const char *component_id, void* data)
 {
